<?php
/**
 * @file
 * Contains WOT Rules integration implementation.
 */

/**
 * Implements hook_rules_condition_info().
 */
function wot_rules_condition_info() {
  return array(
    'wot_contains_untrusted_urls' => array(
      'label' => t('Contains untrusted URLs'),
      'parameter' => array(
        'content' => array(
          'label' => t('Content'),
          'description' => t('Evaluated content which may have untrusted links included.'),
          'type' => 'text',
        ),
        'value_reputation' => array(
          'label' => t('Minimum reputation rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
        'value_confidence' => array(
          'label' => t('Minimum confidence rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
      ),
      'group' => t('Web Of Trust'),
      'callbacks' => array('execute' => 'wot_contains_untrusted_urls'),
    ),
    'wot_contains_unreliable_vendor_urls' => array(
      'label' => t('Contains unreliable vendor URLs'),
      'parameter' => array(
        'content' => array(
          'label' => t('Content'),
          'description' => t('Evaluated content which may have unreliable vendor URLs.'),
          'type' => 'text',
        ),
        'value_reputation' => array(
          'label' => t('Minimum reputation rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
        'value_confidence' => array(
          'label' => t('Minimum confidence rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
      ),
      'group' => t('Web Of Trust'),
      'callbacks' => array('execute' => 'wot_contains_unreliable_vendor_urls'),
    ),
    'wot_contains_urls_which_violates_privacy' => array(
      'label' => t('Contains URLs which violates privacy'),
      'parameter' => array(
        'content' => array(
          'label' => t('Content'),
          'description' => t('Evaluated content which may violate privacy.'),
          'type' => 'text',
        ),
        'value_reputation' => array(
          'label' => t('Minimum reputation rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
        'value_confidence' => array(
          'label' => t('Minimum confidence rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
      ),
      'group' => t('Web Of Trust'),
      'callbacks' => array('execute' => 'wot_contains_urls_which_violates_privacy'),
    ),
    'wot_contains_urls_which_are_unsafe_for_children' => array(
      'label' => t('Contains URLs which are unsafe for children'),
      'parameter' => array(
        'content' => array(
          'label' => t('Content'),
          'description' => t('Evaluated content which may be unsafe for children.'),
          'type' => 'text',
        ),
        'value_reputation' => array(
          'label' => t('Minimum reputation rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
        'value_confidence' => array(
          'label' => t('Minimum confidence rating'),
          'description' => t('What is the minimum rating for passing the evaluation?'),
          'type' => 'text',
          'optional' => TRUE,
          'allow null' => TRUE,
        ),
      ),
      'group' => t('Web Of Trust'),
      'callbacks' => array('execute' => 'wot_contains_urls_which_are_unsafe_for_children'),
    ),
  );
}

/**
 * Callback function for rule "Contains untrusted URLs".
 *
 * @see wot_rules_condition_info()
 * @see wot_contains_urls_of_component()
 */
function wot_contains_untrusted_urls($content, $reputation = NULL, $confidence = NULL) {
  return wot_contains_urls_of_component($content, MyWOTDrupalClient::COMPONENT_TRUSTWORTHINESS, $reputation, $confidence);
}

/**
 * Callback function for rule "Contains unreliable vendor URLs".
 *
 * @see wot_rules_condition_info()
 * @see wot_contains_urls_of_component()
 */
function wot_contains_unreliable_vendor_urls($content, $reputation = NULL, $confidence = NULL) {
  return wot_contains_urls_of_component($content, MyWOTDrupalClient::COMPONENT_VENDOR_RELIABILITY, $reputation, $confidence);
}

/**
 * Callback function for rule "Contains URLs which violates privacy".
 *
 * @see wot_rules_condition_info()
 * @see wot_contains_urls_of_component()
 */
function wot_contains_urls_which_violates_privacy($content, $reputation = NULL, $confidence = NULL) {
  return wot_contains_urls_of_component($content, MyWOTDrupalClient::COMPONENT_PRIVACY, $reputation, $confidence);
}

/**
 * Callback function for rule "Contains which are unsafe for children".
 *
 * @see wot_rules_condition_info()
 * @see wot_contains_urls_of_component()
 */
function wot_contains_urls_which_are_unsafe_for_children($content, $reputation = NULL, $confidence = NULL) {
  return wot_contains_urls_of_component($content, MyWOTDrupalClient::COMPONENT_CHILD_SAFETY, $reputation, $confidence);
}
